@@ -2,7 +2,6 @@ from daily import *
 import requests
 from .daily_call import DailyCall
 
-
 SAMPLE_RATE = 16000
 CHANNELS = 1
 
@@ -10,18 +9,17 @@ CHANNELS = 1
 def create_web_call(api_url, api_key, assistant):
     url = f"{api_url}/call/web"
     headers = {
-        'Authorization': api_key,
+        'Authorization': 'Bearer ' + api_key,
         'Content-Type': 'application/json'
     }
     response = requests.post(url, headers=headers, json=assistant)
-
+    data = response.json()
     if response.status_code == 201:
-        data = response.json()
         call_id = data.get('id')
         web_call_url = data.get('webCallUrl')
         return call_id, web_call_url
     else:
-        print(f"Error: {response.status_code}")
+        print(f"Error: {data['message']}")
         return None
 
 
@@ -40,12 +38,14 @@ class Vapi:
         call_id, web_call_url = create_web_call(
             self.api_url, self.api_key, assistant)
 
-        print('Joining call... ' + web_call_url)
-        print("Call ID: " + call_id)
+        print('Joining call... ' + call_id)
 
-        if (web_call_url):
-            self.__client = DailyCall()
-            self.__client.join(web_call_url)
+        if not web_call_url:
+            raise Exception("Error: Unable to create call.")
+
+        self.__client = DailyCall()
+        self.__client.join(web_call_url)
 
     def stop(self):
         self.__client.leave()
+        self.__client = None
